styling_enabled

Function styling_enabled 

pub fn styling_enabled() -> bool
Whether the Debug impl of Error applies terminal styling. Returns false only if “supports-color” is enabled and the [supports_color] crate does not detect a terminal that wants styling. Note that the Display impl is never styled.